#[non_exhaustive]pub enum BuildIdError {
Empty,
TooLong {
length: usize,
maximum: usize,
},
OddHexLength {
length: usize,
},
InvalidHex {
index: usize,
byte: u8,
},
}Expand description
Build identifier validation error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
Build identifiers used as cache keys may not be empty.
TooLong
The encoded identifier would exceed the filesystem component limit.
OddHexLength
A hexadecimal representation contains an incomplete byte.
InvalidHex
A hexadecimal representation contains a non-hexadecimal byte.