#[non_exhaustive]pub enum Error {
Io {
operation: &'static str,
path: PathBuf,
source: Error,
},
InsecureDirectory {
path: PathBuf,
},
UntrustedEntry {
path: PathBuf,
},
CacheHomeUnavailable,
InvalidApplicationId {
value: PathBuf,
},
InvalidGsym(Box<InvalidGsymError>),
BuildIdMismatch(Box<BuildIdMismatchError>),
InvalidFailureTtl {
lifetime: Duration,
maximum: Duration,
},
FailureExpirationUnrepresentable {
now: SystemTime,
lifetime: Duration,
},
}Expand description
Cache operation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
A filesystem operation failed.
Fields
InsecureDirectory
A cache directory is missing, untrusted, or unsafe to traverse.
UntrustedEntry
A cache entry is not an owned regular file.
No absolute XDG cache directory or home directory is available.
InvalidApplicationId
An XDG application identifier is not one normal path component.
InvalidGsym(Box<InvalidGsymError>)
A cache file is not valid GSYM.
BuildIdMismatch(Box<BuildIdMismatchError>)
The GSYM build identifier differs from its cache key.
InvalidFailureTtl
A negative-cache lifetime is zero or exceeds the maximum.
FailureExpirationUnrepresentable
A negative-cache expiration cannot be represented by the system clock.
Fields

now: SystemTimeClock value used to calculate the expiration.