PopulationOutcome

Enum PopulationOutcome 

pub enum PopulationOutcome<'cache> {
    Acquired(Population<'cache>),
    Busy,
    Suppressed(CachedFailure),
    Present(CacheEntry),
}
Outcome of trying to acquire population ownership.

Variants



Acquired(Population<'cache>)

The caller owns population for this build identifier.



Busy

Another process currently owns the same bounded lock slot.

Lock-slot collisions may delay an unrelated build ID.



Suppressed(CachedFailure)

A cached failure suppresses population until its expiration.



Present(CacheEntry)

Population completed before the lock was needed or acquired.