pub struct CacheEpoch(/* private fields */);Expand description
Version of the conversion policy used to create cached GSYM files.
Incrementing the epoch creates a namespace without reusing artifacts from an older conversion policy.
Implementations