#[non_exhaustive]pub struct ScrubReport {
pub checked: u64,
pub removed_corrupt: u64,
pub removed_temporary: u64,
pub removed_negative: u64,
pub removed_access: u64,
pub skipped_busy: u64,
}Expand description
Measurements from a completed scrub pass.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.checked: u64Number of immutable GSYM objects fully verified.
removed_corrupt: u64Number of malformed or build-ID-mismatched objects removed.
removed_temporary: u64Number of old crash-leftover staging files removed.
removed_negative: u64Number of expired or malformed negative records removed.
removed_access: u64Number of access markers without a corresponding object removed.
skipped_busy: u64Number of objects or staging files skipped because population was active.